
# Usage
We provide instructions how to install dependencies via conda.
First, download the repository locally:

Then, install PyTorch 1.5+ and torchvision 0.6+:
```
conda install -c pytorch pytorch torchvision
```
Install pycocotools (for evaluation on COCO) and scipy (for training):
```
conda install cython scipy
pip install -U 'git+https://github.com/cocodataset/cocoapi.git#subdirectory=PythonAPI'
```

## Data preparation


We expect the directory structure to be the following:
```
path/to/coco/
  train.json
  valid.json
```
json files provided in path_to_coco is similar to the annotation json files in COCO, it should contain following attributes apart from standard COCO format
"images" :  video_id, frame_id
"annotations":  video_id, frame_id, extra: {instance_id, attributes}

where, 
video_id denotes the video sequence,

frame_id denotes the frame number in the given sequence,

instance_id denotes a unique id given to each pig,

attributes is the list of activities performed by the pig (It should contain either 'Active' or 'Inactive')


Note: file_name shoud contain absolute path of the image.

Annotations should be present in a sequential form, i.e, all frames of a given video_id should be in a sequential form. 



## Training Starformer

To train Starformer for 60 epochs with learning rate 2e-4 and batch-size 4, run: 
```
python main.py --masks --coco_path /path/to/coco --dataset_file pig_dataset --output_dir /output/path/model --lr 2e-4 --epochs 60 --batch_size 4
```
For Action Loss: --action_loss_coef 1
For Spatio-Temporal Contrastive Loss: --track --track_loss_coef 0.1. (if --track is enabled, batch_size must be 3)


## Evaluation
```
python main.py --masks --eval --coco_path /path/to/coco --dataset_file pig_dataset --resume path/to/model 
```
